@@ -516,13 +516,7 @@ impl FileCenter {
             }))
     }
 
-    async fn create_file_item(
-        &self,
-        mut document: Document,
-    ) -> Result<
-        FileItem<impl Stream<Item = Result<Cursor<Vec<u8>>, io::Error>> + Unpin>,
-        FileCenterError,
-    > {
+    async fn create_file_item(&self, mut document: Document) -> Result<FileItem, FileCenterError> {
         let file_id = match document
             .remove("_id")
             .ok_or(FileCenterError::DocumentError(ValueAccessError::NotPresent))?
@@ -608,7 +602,7 @@ impl FileCenter {
 
                 let stream = self.open_download_stream(file_id).await?;
 
-                FileData::Stream(stream)
+                FileData::Stream(Box::new(stream))
             }
         };
 
@@ -646,10 +640,7 @@ impl FileCenter {
     pub async fn get_file_item_by_id(
         &self,
         id: ObjectId,
-    ) -> Result<
-        Option<FileItem<impl Stream<Item = Result<Cursor<Vec<u8>>, io::Error>> + Unpin>>,
-        FileCenterError,
-    > {
+    ) -> Result<Option<FileItem>, FileCenterError> {
         let collection_files = &self.collections.files;
 
         let mut options = FindOneOptions::default();
